/**
 * -------------------------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.
 * See License in the project root for license information.
 * -------------------------------------------------------------------------------------------
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SessionCache, storageAvailable } from '../utils/SessionCache';
/**
 * Implements Middleware for the Mock Client to escape
 * the graph url from the request
 *
 * @class MockMiddleware
 * @implements {Middleware}
 */
export class MockMiddleware {
    static get _sessionCache() {
        if (!this._cache && storageAvailable('sessionStorage')) {
            this._cache = new SessionCache();
        }
        return this._cache;
    }
    execute(context) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const baseUrl = yield MockMiddleware.getBaseUrl();
                context.request = baseUrl + encodeURIComponent(context.request);
            }
            catch (error) {
                // ignore error
            }
            return yield this._nextMiddleware.execute(context);
        });
    }
    /**
     * Handles setting of next middleware
     *
     * @param {Middleware} next
     * @memberof SdkVersionMiddleware
     */
    setNext(next) {
        this._nextMiddleware = next;
    }
    /**
     * Gets the base url for the mock graph, either from the session cache or from the endpoint service
     *
     * @static
     * @return {string} the base url for the mock graph to use.
     * @memberof MockMiddleware
     */
    static getBaseUrl() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this._baseUrl) {
                const sessionEndpoint = (_a = this._sessionCache) === null || _a === void 0 ? void 0 : _a.getItem('endpointURL');
                if (sessionEndpoint) {
                    this._baseUrl = sessionEndpoint;
                }
                else {
                    try {
                        // get the url we should be using from the endpoint service
                        const response = yield fetch('https://cdn.graph.office.net/en-us/graph/api/proxy/endpoint');
                        const base = yield response.json();
                        if (typeof base !== 'string') {
                            MockMiddleware.setBaseFallbackUrl();
                        }
                        else {
                            this._baseUrl = base + '?url=';
                        }
                    }
                    catch (_c) {
                        // fallback to hardcoded value
                        MockMiddleware.setBaseFallbackUrl();
                    }
                    (_b = this._sessionCache) === null || _b === void 0 ? void 0 : _b.setItem('endpointURL', this._baseUrl);
                }
            }
            return this._baseUrl;
        });
    }
    static setBaseFallbackUrl() {
        this._baseUrl = 'https://graph.office.net/en-us/graph/api/proxy?url=';
    }
}
//# sourceMappingURL=MockMiddleware.js.map